@@ -1,6 +1,6 @@
 package Net::OAuth::LP::Client;
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use strictures 1;
 use Moo;
@@ -126,6 +126,54 @@ method update ($resource, $params) {
     $self->_request($resource, $params, 'PATCH');
 }
 
+method login_with_creds {
+    my $ua      = LWP::UserAgent->new();
+    my $request = Net::OAuth->request('consumer')->new(
+        consumer_key     => $self->consumer_key,
+        consumer_secret  => '',
+        request_url      => $self->request_token_url,
+        request_method   => 'POST',
+        signature_method => 'PLAINTEXT',
+        timestamp        => time,
+        nonce            => $self->_nonce,
+    );
+
+    $request->sign;
+    my $res =
+      $ua->request(POST $request->to_url, Content => $request->to_post_body);
+
+    die "Failed to get response" unless $res->is_success;
+    my $response =
+      Net::OAuth->response('request token')->from_post_body($res->content);
+    my $_token        = $response->token;
+    my $_token_secret = $response->token_secret;
+    open_browser($self->authorize_token_url . "?oauth_token=" . $_token);
+
+    print "Pulling authorization credentials.\n";
+
+    $request = Net::OAuth->request('access token')->new(
+        consumer_key     => $self->consumer_key,
+        consumer_secret  => '',
+        token            => $_token,
+        token_secret     => $_token_secret,
+        request_url      => $self->access_token_url,
+        request_method   => 'POST',
+        signature_method => 'PLAINTEXT',
+        timestamp        => time,
+        nonce            => $self->_nonce
+    );
+
+    $request->sign;
+
+    $res =
+      $ua->request(POST $request->to_url, Content => $request->to_post_body);
+    die "Failed to get response" unless $res->is_success;
+    $response =
+      Net::OAuth->response('access token')->from_post_body($res->content);
+    $self->access_token($response->token);
+    $self->access_token_secret($response->token_secret);
+}
+
 1; # End of Net::OAuth::LP::Client
 
 __END__
@@ -134,9 +182,23 @@ __END__
 
 Net::OAuth::LP::Client - Launchpad.net Client routines
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
-This isn't meant to be called directly but inherited from exposed Net::OAuth::LP::Models.
+    use Net::OAuth::LP::Client;
+    my $lp = Net::OAuth::LP::Client->new;
+    $lp->login_with_creds;
+
+=head1 METHODS
+
+=head2 B<login_with_creds>
+
+    use Net::OAuth::LP::Client;
+
+    my $lp = Net::OAuth::LP::Client->new;
+    $lp->consumer_key('my-lp-app');
+
+    # Authorize yourself
+    $lp->login_with_creds;
 
 =head1 DEVELOPMENT
 
