@@ -1,6 +1,6 @@
 package Net::OAuth::LP::Models::Bug;
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use strictures 1;
 use Net::OAuth::LP::Models::Tasks;
@@ -240,7 +240,7 @@ Interface to setting/retrieving bug information
                                         access_token_secret => 'fdsafsda');
     my $b = Net::OAuth::LP::Models::Bug->new(c => $c);
     $b->find(1);
-    say $b->description;
+    say $b->title;
 
 =head1 ATTRIBUTES
 
